# Unknown error
error_message: str = "API tester error"
wrong_http_method_error_message: str = "wrong http method"
http_method_have_wrong_type: str = "get wrong type param"
# get data error
get_data_error_message: str = "API tester can't get api data error"
# Http Method error
get_error_message: str = "API tester get error"
get_json_error_message: str = "API tester get json error"
put_error_message: str = "API tester put error"
delete_error_message: str = "API tester delete error"
post_error_message: str = "API tester post error"
head_error_message: str = "API tester head error"
options_error_message: str = "API tester options error"
patch_error_message: str = "API tester patch error"
session_error_message: str = "API tester session error"
# response code error
response_code_error: str = "API tester get wrong response code"
# response body error
response_body_error: str = "API tester get wrong response body"
# response timeout error
response_timeout_error: str = "API tester timeout"
# response history error
response_history_error: str = "API tester history error"
# response encoding error
response_encoding_error: str = "API tester encoding error"
# response cookies error
response_cookies_error: str = "API tester cookies error"
# response headers error
response_headers_error: str = "API tester headers error"
# response content error
response_content_error: str = "API tester content error"
# response text error
response_text_error: str = "API tester text error"
# execute action error
execute_action_error: str = "can't execute action"
# json error
cant_find_json_error: str = "can't find json"
cant_save_json_error: str = "can't save json"
cant_save_json_report_record_us_null: str = "can't save json record is null"
cant_reformat_json_error: str = "can't reformat json is type right?"
cant_find_element_in_json_error: str = "can't find element in json"
json_type_error: str = "json type error"
wrong_json_data_error: str = "can't parser json"
# XML error
cant_read_xml_error: str = "can't read xml"
xml_type_error: str = "xml type error"
# Executor error
executor_data_error: str = "executor receive wrong data"
executor_list_error: str = "executor receive wrong data list is none or wrong type"
# API data check
status_code_error: str = "request status code error"
status_text_error: str = "request text error"
status_content_error: str = "request content error"
status_headers_error: str = "request headers error"
status_history_error: str = "request history error"
status_encoding_error: str = "request encoding error"
status_cookies_error: str = "request cookies error"
status_elapsed_error: str = "request elapsed error"
status_requests_method_error: str = "requests method error"
status_requests_url_error: str = "requests url error"
status_requests_body_error: str = "requests body error"
# HTML
html_generate_no_data_tag: str = "record is None"
# add command
add_command_exception_tag: str = "command value type should be as method or function"
# argparse
argparse_get_wrong_data: str = "argparse receive wrong data"
# Callback executor
get_bad_trigger_method: str = "get bad trigger method, only accept kwargs and args"
get_bad_trigger_function: str = "get bad trigger function only accept function in event_dict"
